# AI Collaboration Platform

## Install

    pip install aicp


## Prerequisites

    * Python 3.6+


## Usage

Login to the platform using the following command:

    aicp login


Create service with <directory> as the directory using the following command:

    aicp service create <directory>


or import service from a local directory using the following command:

    aicp service import <directory> 